
using System;
using Gtk;
using IPod;
using Mono.Unix;

namespace Dopi {

    public class PlaylistWindow : Window {

        private SongDatabase db;
        private PlaylistCombo combo;
        private PlaylistView view;

        private Button createButton;
        private Button deleteButton;
        
        public SongDatabase SongDatabase {
            get { return db; }
            set {
                db = value;
                view.SongDatabase = db;
                combo.SongDatabase = db;
                SetSensitive ();
            }
        }
        
        public PlaylistWindow () : base ("Dopi - Playlist Editor") {
            this.DefaultHeight = 400;
            VBox vbox = new VBox (false, 6);
            vbox.BorderWidth = 6;
            HBox hbox = new HBox (false, 6);

            vbox.PackStart (hbox, false, false, 0);

            combo = new PlaylistCombo (db);
            combo.Changed += OnPlaylistChanged;
            hbox.PackStart (combo, false, false, 0);

            createButton = Utility.CreateButton (Stock.New, Catalog.GetString ("_Create"));
            createButton.Clicked += OnNewPlaylist;
            hbox.PackStart (createButton, false, false, 0);

            deleteButton = Utility.CreateButton (Stock.Delete, Catalog.GetString ("_Remove"));
            deleteButton.Clicked += OnDeletePlaylist;
            hbox.PackStart (deleteButton, false, false, 0);
            
            ScrolledWindow scroll = new ScrolledWindow ();
            scroll.HscrollbarPolicy = PolicyType.Automatic;
            scroll.VscrollbarPolicy = PolicyType.Automatic;
            scroll.ShadowType = ShadowType.EtchedIn;

            view = new PlaylistView ();
            view.SongDatabase = db;
            view.Playlist = combo.ActivePlaylist;
            
            scroll.Add (view);
            vbox.PackStart (scroll, true, true, 0);

            this.DeleteEvent += OnDeleteEvent;

            vbox.ShowAll ();
            Add (vbox);
        }

        public void Refresh () {
            combo.Refresh ();
            view.Refresh ();
        }

        public void RefreshSong (Song song) {
            view.RefreshSong (song);
        }

        private void SetSensitive () {
            if (db == null) {
                this.Sensitive = false;
            } else {
                this.Sensitive = true;
            }
        }
                

        private void OnDeleteEvent (object o, DeleteEventArgs args) {
            args.RetVal = true;
            this.Hide ();
        }

        private void OnPlaylistChanged (object o, EventArgs args) {
            view.Playlist = combo.ActivePlaylist;
            view.Refresh ();

            if (combo.ActivePlaylist == null) {
                deleteButton.Sensitive = false;
            } else {
                deleteButton.Sensitive = true;
            }
        }

        private void OnNewPlaylist (object o, EventArgs args) {
            string name = null;
            int i = 0;
            
            while (true) {
                if (i == 0) {
                    name = "New Playlist";
                } else {
                    name = String.Format ("New Playlist {0}", i);
                }

                if (db.LookupPlaylist (name) == null)
                    break;

                i++;
            }

            Playlist pl = db.CreatePlaylist (name);
            combo.ActivePlaylist = pl;
        }

        private void OnDeletePlaylist (object o, EventArgs args) {
            Playlist pl = combo.ActivePlaylist;

            if (pl != null) {
                db.RemovePlaylist (pl);
            }
        }
    }
}
